@@ -24,6 +24,7 @@ convert a PRCS project to a new Mercurial repository.
 """
 
 from __future__ import absolute_import, unicode_literals
+
 from hgext.convert import convcmd
 from .prcs import prcs_source
 
@@ -32,7 +33,7 @@ testedwith = "5.2.2"
 
 def extsetup(ui):
     """
-    set up the 'convert_prcs' extension
+    Set up the 'convert_prcs' extension.
     """
     convcmd.source_converters.append(
         (b"prcs", prcs_source, b"branchsort")
